@@ -55,7 +55,7 @@ def login(app, username, password):
     if response.is_redirect:
         raise AuthenticationError()
 
-    return http.process_response(response).json()
+    return response.json()
 
 
 def get_browser_login_url(app):
@@ -79,9 +79,7 @@ def request_access_token(app, authorization_code):
         'redirect_uri': 'urn:ietf:wg:oauth:2.0:oob',
     }
 
-    response = http.anon_post(url, data, allow_redirects=False)
-
-    return http.process_response(response).json()
+    return http.anon_post(url, data, allow_redirects=False).json()
 
 
 def post_status(
@@ -195,7 +193,7 @@ def public_timeline_generator(instance, local=False, limit=20):
 
 
 def tag_timeline_generator(instance, hashtag, local=False, limit=20):
-    path = '/api/v1/timelines/tag/{}'.format(hashtag)
+    path = '/api/v1/timelines/tag/{}'.format(quote(hashtag))
     params = {'local': str_bool(local), 'limit': limit}
     return _anon_timeline_generator(instance, path, params)
 
@@ -212,7 +210,7 @@ def upload_media(app, user, file):
 
 
 def search(app, user, query, resolve):
-    return http.get(app, user, '/api/v1/search', {
+    return http.get(app, user, '/api/v2/search', {
         'q': query,
         'resolve': resolve,
     }).json()
