@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 
-import os
-import sys
 import logging
+import os
+import shutil
+import sys
 
 from argparse import ArgumentParser, FileType, ArgumentTypeError
 from collections import namedtuple
@@ -39,10 +40,25 @@ def timeline_count(value):
     return n
 
 
+def editor(value):
+    if not value:
+        raise ArgumentTypeError(
+            "Editor not specified in --editor option and $EDITOR environment "
+            "variable not set."
+        )
+
+    # Check editor executable exists
+    exe = shutil.which(value)
+    if not exe:
+        raise ArgumentTypeError("Editor `{}` not found".format(value))
+
+    return exe
+
+
 Command = namedtuple("Command", ["name", "description", "require_auth", "arguments"])
 
 
-# Aruguments added to every command
+# Arguments added to every command
 common_args = [
     (["--no-color"], {
         "help": "don't use ANSI colors in output",
@@ -180,6 +196,21 @@ AUTH_COMMANDS = [
     ),
 ]
 
+TUI_COMMANDS = [
+    Command(
+        name="tui",
+        description="Launches the toot terminal user interface",
+        arguments=[],
+        require_auth=True,
+    ),
+    Command(
+        name="curses",
+        description="An experimental timeline app (DEPRECATED, use 'toot tui' instead)",
+        arguments=curses_args,
+        require_auth=False,
+    ),
+]
+
 
 READ_COMMANDS = [
     Command(
@@ -253,12 +284,6 @@ READ_COMMANDS = [
         arguments=timeline_args,
         require_auth=True,
     ),
-    Command(
-        name="curses",
-        description="An experimental timeline app (doesn't work on Windows)",
-        arguments=curses_args,
-        require_auth=False,
-    ),
 ]
 
 POST_COMMANDS = [
@@ -298,6 +323,13 @@ POST_COMMANDS = [
                 "type": language,
                 "help": "ISO 639-2 language code of the toot, to skip automatic detection",
             }),
+            (["-e", "--editor"], {
+                "type": editor,
+                "nargs": "?",
+                "const": os.getenv("EDITOR", ""),  # option given without value
+                "help": "Specify an editor to compose your toot, "
+                        "defaults to editor defined in $EDITOR env variable.",
+            }),
         ],
         require_auth=True,
     ),
@@ -416,7 +448,7 @@ ACCOUNTS_COMMANDS = [
     ),
 ]
 
-COMMANDS = AUTH_COMMANDS + READ_COMMANDS + POST_COMMANDS + STATUS_COMMANDS + ACCOUNTS_COMMANDS
+COMMANDS = AUTH_COMMANDS + READ_COMMANDS + TUI_COMMANDS + POST_COMMANDS + STATUS_COMMANDS + ACCOUNTS_COMMANDS
 
 
 def print_usage():
@@ -424,6 +456,7 @@ def print_usage():
 
     groups = [
         ("Authentication", AUTH_COMMANDS),
+        ("TUI", TUI_COMMANDS),
         ("Read", READ_COMMANDS),
         ("Post", POST_COMMANDS),
         ("Status", STATUS_COMMANDS),
@@ -500,12 +533,6 @@ def main():
         filename = os.getenv("TOOT_LOG_FILE")
         logging.basicConfig(level=logging.DEBUG, filename=filename)
 
-    # If something is piped in, append it to commandline arguments
-    if not sys.stdin.isatty():
-        stdin = sys.stdin.read()
-        if stdin:
-            sys.argv.append(stdin)
-
     command_name = sys.argv[1] if len(sys.argv) > 1 else None
     args = sys.argv[2:]
 
@@ -519,5 +546,5 @@ def main():
     except (ConsoleError, ApiError) as e:
         print_err(str(e))
         sys.exit(1)
-    except KeyboardInterrupt as e:
+    except KeyboardInterrupt:
         pass
